@@ -1,10 +1,6 @@
-﻿use strict;
-use warnings;
 package RDF::Lazy::Blank;
-{
-  $RDF::Lazy::Blank::VERSION = '0.081';
-}
-#ABSTRACT: Blank node in a RDF::Lazy graph
+use strict;
+use warnings;
 
 use base 'RDF::Lazy::Node';
 use Scalar::Util qw(blessed);
@@ -31,20 +27,15 @@ sub str {
     '_:'.shift->trine->blank_identifier
 }
 
+*qname = *str;
+
 1;
-
-
 __END__
-=pod
 
 =head1 NAME
 
 RDF::Lazy::Blank - Blank node in a RDF::Lazy graph
 
-=head1 VERSION
-
-version 0.081
-
 =head1 DESCRIPTION
 
 You should not directly create instances of this class.
@@ -60,16 +51,4 @@ Return the local identifier of this node.
 
 Return the local identifier, prepended by "C<_:>".
 
-=head1 AUTHOR
-
-Jakob Voß <voss@gbv.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
-
