@@ -1,10 +1,7 @@
-﻿use strict;
-use warnings;
 package RDF::Lazy::Literal;
-{
-  $RDF::Lazy::Literal::VERSION = '0.081';
-}
-#ABSTRACT: Literal node in a RDF::Lazy graph
+use v5.10;
+use strict;
+use warnings;
 
 use base 'RDF::Lazy::Node';
 use Scalar::Util qw(blessed);
@@ -18,7 +15,7 @@ our $LANGTAG = qr/^(([a-z]{2,8}|[a-z]{2,3}-[a-z]{3})(-[a-z0-9_]+)?-?)$/i;
 sub new {
     my $class   = shift;
     my $graph   = shift || RDF::Lazy->new;
-    my $literal = shift;
+    my $literal = shift // '';
 
     my ($language, $datatype) = @_;
 
@@ -47,7 +44,7 @@ sub lang {
     my $lang = $self->trine->literal_value_language;
     return $lang if not @_ or not $lang;
 
-    my $xxx = shift || "";
+    my $xxx = lc(shift || "");
     $xxx =~ s/_/-/g;
     return unless $xxx =~ $LANGTAG;
 
@@ -63,9 +60,9 @@ sub datatype {
     my $type = $self->graph->resource( $self->trine->literal_datatype );
     return $type unless @_ and $type;
 
-    foreach my $t (@_) {
-        $t = $self->graph->uri( $t );
-        return 1 if $t->is_resource and $t eq $type;
+    foreach (@_) {
+        my $t = $self->graph->uri( $_ );
+        return 1 if $t->is_resource and $t->str eq $type->str;
     }
 
     return;
@@ -84,19 +81,12 @@ sub _autoload {
 }
 
 1;
-
-
 __END__
-=pod
 
 =head1 NAME
 
 RDF::Lazy::Literal - Literal node in a RDF::Lazy graph
 
-=head1 VERSION
-
-version 0.081
-
 =head1 DESCRIPTION
 
 You should not directly create instances of this class.
@@ -132,16 +122,4 @@ Can also be used to checks whether the datatype matches, for instance:
 
     $node->datatype('xsd:integer','xsd:double');
 
-=head1 AUTHOR
-
-Jakob Voß <voss@gbv.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
-
